@@ -1,4 +1,6 @@
 #!/usr/bin/perl
+use Env qw($windir);
+if( $windir eq "" ) { print "Using UNIX command line options.\n"; } else { print "Uinsg Windows command line options.\n"; }
 
 	$some_dir = "Output/";
     	opendir(DIR, $some_dir) || die "can't opendir $some_dir: $!";
@@ -20,13 +22,18 @@
 
 			print " to " . $outfile . "\n";
 
-			# Comment or uncommnet the following lines to function with Windows/Unix
-			# Unix
-			#$cmd = "cp Output/$infile/* $outfile";
-			# Windows
-			$infile =~ s/\//\\/g;
-			$outfile =~ s/\//\\/g;
-			$cmd = "copy Output\\$infile\\* $outfile";
+			if( $windir eq "" )
+				{
+				# Unix
+				$cmd = "cp Output/$infile/* $outfile";
+				}
+			else
+				{
+				# Windows
+				$infile =~ s/\//\\/g;
+				$outfile =~ s/\//\\/g;
+				$cmd = "copy Output\\$infile\\* $outfile";
+				}
 
 			system( $cmd );
 			}
